==> VoiceOver-1.0.1.tar.bz2: VoiceOver-1.0.1/voxcheckconfig.c <==
/*
** voxcheckconfig - Configuration file validator for voxd VoiceOver daemon
** Copyright (C) 2017  Lew Pitcher
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**
** Lew Pitcher <lew.pitcher@digitalfreehold.ca>
*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

#include "voxconfig.h"
#include "voxd.h"

int main(int argc, char *argv[])
{
  int rc = EXIT_FAILURE;
  int	opt;
  extern char *optarg;
  char	*ConfigPath = NULL;
  int	Rewrite = 0;
  int	argerrors = 0;

  while ((opt = getopt(argc,argv,"c:r")) != -1)
  {
    switch (opt)
    {
      case 'c':	/* change config path */
	free(ConfigPath);
	ConfigPath = strdup(optarg);
	break;

      case 'r':	/* set rewrite flag */
	Rewrite = 1;
	break;

      default:	/* anything else */
	argerrors = 1;
	break;
    }
  }
  if (ConfigPath == NULL) ConfigPath = strdup(CONFIGPATH);

  if (argerrors == 0 && argc - optind == 0)
  {
    struct show *Show;

    if ((Show = OpenShow(ConfigPath)))
    {
      if (Rewrite)
      {
	struct actor *Actor;
	struct role  *Role;

	printf("# voxd config file %s\n\n",ConfigPath);
	if ((Show->prologue || Show->epilogue))
	{
	  puts("; voxd will announce itself");
	  if (Show->prologue)
	    printf("Prologue = \"%s\"\t; This spoken at startup\n",Show->prologue);
	  if (Show->epilogue)
	    printf("Epilogue = \"%s\"\t; This spoken at shutdown\n",Show->epilogue);
	  puts("");
	}

	puts("; The ACTORS and their voices");
	for (Actor = Show->actors; Actor; Actor = Actor->actorNext)
	{
	  /* Generate a comment to document the internally-generated STANDIN_ACTOR */
	  if (strcmp(STANDIN_ACTOR,Actor->actorName) == 0) printf("; ");

	  printf("%s has voice \"%s\"",Actor->actorName, Actor->voicePath);
	  if (Actor->voiceTempo != 0.0 || Actor->voicePitch != 0.0 || Actor->voiceIntonation != 0.0)
	  {
	    int MayNeedComma = 0;

	    printf(" (");
	    if (Actor->voiceTempo != 0.0)
	    {
	      printf("tempo=%f",Actor->voiceTempo);
	      MayNeedComma = 1;
	    }

	    if (Actor->voicePitch != 0.0)
	    {
	      printf("%spitch=%f",MayNeedComma?", ":"",Actor->voicePitch);
	      MayNeedComma = 1;
	    }

	    if (Actor->voiceIntonation != 0.0)
	    {
	      printf("%sintonation=%f",MayNeedComma?", ":"",Actor->voiceIntonation);
	    }
	    printf(")");
	  }
	  puts("");
	}

	puts("\n; The ROLES and their ACTORS");
	for (Role = Show->roles; Role; Role = Role->roleNext)
	{
	  /* Generate a comment to document the internally-generated STANDIN_ROLE */
	  if (strcmp(STANDIN_ROLE,Role->roleName) == 0 && strcmp(STANDIN_ACTOR,Role->roleActor->actorName) == 0)
	    printf("; ");
	  printf("%s is voiced by %s\n",Role->roleName,Role->roleActor->actorName);
	}
      }
      else printf("%s looks clean to me\n",ConfigPath);
      rc = EXIT_SUCCESS;
    }
    else printf("The voiceover config file (at %s) has errors\n",ConfigPath);
  }
  else fprintf(stderr,"Usage: %s [-c configpath] [-r]\n",argv[0]);

  return rc;
}

==> VoiceOver-1.0.5.tar.bz2: VoiceOver-1.0.5/voxcheckconfig.c <==
/*
** voxcheckconfig - Configuration file validator for voxd VoiceOver daemon
** Copyright (C) 2017, 2020  Lew Pitcher
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**
** Lew Pitcher <lew.pitcher@digitalfreehold.ca>
*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

#include "voxconfig.h"
#include "voxd.h"

int main(int argc, char *argv[])
{
  int rc = EXIT_FAILURE;
  int	opt;
  extern char *optarg;
  char	*ConfigPath = NULL;
  int	Rewrite = 0;
  int	argerrors = 0;

  while ((opt = getopt(argc,argv,"c:r")) != -1)
  {
    switch (opt)
    {
      case 'c':	/* change config path */
	free(ConfigPath);
	ConfigPath = strdup(optarg);
	break;

      case 'r':	/* set rewrite flag */
	Rewrite = 1;
	break;

      default:	/* anything else */
	argerrors = 1;
	break;
    }
  }
  if (ConfigPath == NULL) ConfigPath = strdup(CONFIGPATH);

  if (argerrors == 0 && argc - optind == 0)
  {
    struct show *Show;

    if ((Show = OpenShow(ConfigPath)))
    {
      if (Rewrite)
      {
        fprintf(stdout,"# voxd config file %s\n\n",ConfigPath);
	WriteShow(stdout,Show);
      }
      else
	printf("%s looks clean to me\n",ConfigPath);
      rc = EXIT_SUCCESS;
    }
    else printf("The voiceover config file (at %s) has errors\n",ConfigPath);
  }
  else fprintf(stderr,"Usage: %s [-c configpath] [-r]\n",argv[0]);

  return rc;
}
